@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1993, 19801990
+ * Copyright (c) 1980, 1990, 1993
  *	The Regents of the University of California.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -140,6 +140,8 @@ makefile(void)
 	if (ofp == 0)
 		err(1, "%s", path("Makefile.new"));
 	fprintf(ofp, "KERN_IDENT=%s\n", ident);
+	fprintf(ofp, "MACHINE=%s\n", machinename);
+	fprintf(ofp, "MACHINE_ARCH=%s\n", machinearch);
 	SLIST_FOREACH_SAFE(op, &mkopt, op_next, t) {
 		fprintf(ofp, "%s=%s", op->op_name, op->op_value);
 		while ((op = SLIST_NEXT(op, op_append)) != NULL)
@@ -152,7 +154,7 @@ makefile(void)
 		fprintf(ofp, "PROFLEVEL=%d\n", profiling);
 	if (*srcdir != '\0')
 		fprintf(ofp,"S=%s\n", srcdir);
-	while (fgets(line, BUFSIZ, ifp) != 0) {
+	while (fgets(line, BUFSIZ, ifp) != NULL) {
 		if (*line != '%') {
 			fprintf(ofp, "%s", line);
 			continue;
@@ -202,14 +204,14 @@ makehints(void)
 		ifp = fopen(hint->hint_name, "r");
 		if (ifp == NULL)
 			err(1, "%s", hint->hint_name);
-		while (fgets(line, BUFSIZ, ifp) != 0) {
+		while (fgets(line, BUFSIZ, ifp) != NULL) {
 			/* zap trailing CR and/or LF */
-			while ((s = rindex(line, '\n')) != NULL)
+			while ((s = strrchr(line, '\n')) != NULL)
 				*s = '\0';
-			while ((s = rindex(line, '\r')) != NULL)
+			while ((s = strrchr(line, '\r')) != NULL)
 				*s = '\0';
 			/* remove # comments */
-			s = index(line, '#');
+			s = strchr(line, '#');
 			if (s)
 				*s = '\0';
 			/* remove any whitespace and " characters */
@@ -264,14 +266,14 @@ makeenv(void)
 	fprintf(ofp, "int envmode = %d;\n", envmode);
 	fprintf(ofp, "char static_env[] = {\n");
 	if (ifp) {
-		while (fgets(line, BUFSIZ, ifp) != 0) {
+		while (fgets(line, BUFSIZ, ifp) != NULL) {
 			/* zap trailing CR and/or LF */
-			while ((s = rindex(line, '\n')) != NULL)
+			while ((s = strrchr(line, '\n')) != NULL)
 				*s = '\0';
-			while ((s = rindex(line, '\r')) != NULL)
+			while ((s = strrchr(line, '\r')) != NULL)
 				*s = '\0';
 			/* remove # comments */
-			s = index(line, '#');
+			s = strchr(line, '#');
 			if (s)
 				*s = '\0';
 			/* remove any whitespace and " characters */
@@ -310,6 +312,7 @@ read_file(char *fname)
 	struct device *dp;
 	struct opt *op;
 	char *wd, *this, *compilewith, *depends, *clean, *warning;
+	const char *objprefix;
 	int compile, match, nreqs, std, filetype,
 	    imp_rule, no_obj, before_depend, mandatory, nowerror;
 
@@ -324,6 +327,7 @@ next:
 	 *	[ compile-with "compile rule" [no-implicit-rule] ]
 	 *      [ dependency "dependency-list"] [ before-depend ]
 	 *	[ clean "file-list"] [ warning "text warning" ]
+	 *	[ obj-prefix "file prefix"]
 	 */
 	wd = get_word(fp);
 	if (wd == (char *)EOF) {
@@ -341,7 +345,8 @@ next:
 	if (eq(wd, "include")) {
 		next_quoted_word(fp, wd);
 		if (wd == 0) {
-			printf("%s: missing include filename.\n", fname);
+			fprintf(stderr, "%s: missing include filename.\n",
+			    fname);
 			exit(1);
 		}
 		(void) snprintf(ifname, sizeof(ifname), "../../%s", wd);
@@ -353,8 +358,7 @@ next:
 	this = ns(wd);
 	next_word(fp, wd);
 	if (wd == 0) {
-		printf("%s: No type for %s.\n",
-		    fname, this);
+		fprintf(stderr, "%s: No type for %s.\n", fname, this);
 		exit(1);
 	}
 	tp = fl_lookup(this);
@@ -371,6 +375,7 @@ next:
 	before_depend = 0;
 	nowerror = 0;
 	filetype = NORMAL;
+	objprefix = "";
 	if (eq(wd, "standard")) {
 		std = 1;
 	/*
@@ -381,8 +386,9 @@ next:
 	} else if (eq(wd, "mandatory")) {
 		mandatory = 1;
 	} else if (!eq(wd, "optional")) {
-		printf("%s: %s must be optional, mandatory or standard\n",
-		       fname, this);
+		fprintf(stderr,
+		    "%s: \"%s\" %s must be optional, mandatory or standard\n",
+		    fname, wd, this);
 		exit(1);
 	}
 nextparam:
@@ -395,7 +401,7 @@ nextparam:
 	}
 	if (eq(wd, "|")) {
 		if (nreqs == 0) {
-			printf("%s: syntax error describing %s\n",
+			fprintf(stderr, "%s: syntax error describing %s\n",
 			    fname, this);
 			exit(1);
 		}
@@ -410,9 +416,9 @@ nextparam:
 	}
 	if (eq(wd, "no-implicit-rule")) {
 		if (compilewith == 0) {
-			printf("%s: alternate rule required when "
-			       "\"no-implicit-rule\" is specified.\n",
-			       fname);
+			fprintf(stderr, "%s: alternate rule required when "
+			    "\"no-implicit-rule\" is specified.\n",
+			    fname);
 		}
 		imp_rule++;
 		goto nextparam;
@@ -424,8 +430,9 @@ nextparam:
 	if (eq(wd, "dependency")) {
 		next_quoted_word(fp, wd);
 		if (wd == 0) {
-			printf("%s: %s missing compile command string.\n",
-			       fname, this);
+			fprintf(stderr,
+			    "%s: %s missing dependency string.\n",
+			    fname, this);
 			exit(1);
 		}
 		depends = ns(wd);
@@ -434,8 +441,8 @@ nextparam:
 	if (eq(wd, "clean")) {
 		next_quoted_word(fp, wd);
 		if (wd == 0) {
-			printf("%s: %s missing clean file list.\n",
-			       fname, this);
+			fprintf(stderr, "%s: %s missing clean file list.\n",
+			    fname, this);
 			exit(1);
 		}
 		clean = ns(wd);
@@ -444,8 +451,9 @@ nextparam:
 	if (eq(wd, "compile-with")) {
 		next_quoted_word(fp, wd);
 		if (wd == 0) {
-			printf("%s: %s missing compile command string.\n",
-			       fname, this);
+			fprintf(stderr,
+			    "%s: %s missing compile command string.\n",
+			    fname, this);
 			exit(1);
 		}
 		compilewith = ns(wd);
@@ -454,13 +462,24 @@ nextparam:
 	if (eq(wd, "warning")) {
 		next_quoted_word(fp, wd);
 		if (wd == 0) {
-			printf("%s: %s missing warning text string.\n",
-				fname, this);
+			fprintf(stderr,
+			    "%s: %s missing warning text string.\n",
+			    fname, this);
 			exit(1);
 		}
 		warning = ns(wd);
 		goto nextparam;
 	}
+	if (eq(wd, "obj-prefix")) {
+		next_quoted_word(fp, wd);
+		if (wd == 0) {
+			printf("%s: %s missing object prefix string.\n",
+				fname, this);
+			exit(1);
+		}
+		objprefix = ns(wd);
+		goto nextparam;
+	}
 	nreqs++;
 	if (eq(wd, "local")) {
 		filetype = LOCAL;
@@ -484,13 +503,14 @@ nextparam:
 			goto nextparam;
 		}
 	if (mandatory) {
-		printf("%s: mandatory device \"%s\" not found\n",
+		fprintf(stderr, "%s: mandatory device \"%s\" not found\n",
 		       fname, wd);
 		exit(1);
 	}
 	if (std) {
-		printf("standard entry %s has a device keyword - %s!\n",
-		       this, wd);
+		fprintf(stderr,
+		    "standard entry %s has a device keyword - %s!\n",
+		    this, wd);
 		exit(1);
 	}
 	SLIST_FOREACH(op, &opt, op_next)
@@ -501,13 +521,13 @@ nextparam:
 
 doneparam:
 	if (std == 0 && nreqs == 0) {
-		printf("%s: what is %s optional on?\n",
+		fprintf(stderr, "%s: what is %s optional on?\n",
 		    fname, this);
 		exit(1);
 	}
 
 	if (wd) {
-		printf("%s: syntax error describing %s\n",
+		fprintf(stderr, "%s: syntax error describing %s\n",
 		    fname, this);
 		exit(1);
 	}
@@ -528,6 +548,7 @@ doneparam:
 	tp->f_depends = depends;
 	tp->f_clean = clean;
 	tp->f_warn = warning;
+	tp->f_objprefix = objprefix;
 	goto next;
 }
 
@@ -612,11 +633,12 @@ do_objs(FILE *fp)
 		cp = sp + (len = strlen(sp)) - 1;
 		och = *cp;
 		*cp = 'o';
+		len += strlen(tp->f_objprefix);
 		if (len + lpos > 72) {
 			lpos = 8;
 			fprintf(fp, "\\\n\t");
 		}
-		fprintf(fp, "%s ", sp);
+		fprintf(fp, "%s%s ", tp->f_objprefix, sp);
 		lpos += len + 1;
 		*cp = och;
 	}
@@ -667,7 +689,7 @@ tail(char *fn)
 {
 	char *cp;
 
-	cp = rindex(fn, '/');
+	cp = strrchr(fn, '/');
 	if (cp == 0)
 		return (fn);
 	return (cp+1);
@@ -683,68 +705,78 @@ do_rules(FILE *f)
 	char *cp, *np, och;
 	struct file_list *ftp;
 	char *compilewith;
+	char cmd[128];
 
 	STAILQ_FOREACH(ftp, &ftab, f_next) {
 		if (ftp->f_warn)
-			printf("WARNING: %s\n", ftp->f_warn);
+			fprintf(stderr, "WARNING: %s\n", ftp->f_warn);
 		cp = (np = ftp->f_fn) + strlen(ftp->f_fn) - 1;
 		och = *cp;
 		if (ftp->f_flags & NO_IMPLCT_RULE) {
 			if (ftp->f_depends)
-				fprintf(f, "%s: %s\n", np, ftp->f_depends);
+				fprintf(f, "%s%s: %s\n",
+					ftp->f_objprefix, np, ftp->f_depends);
 			else
-				fprintf(f, "%s: \n", np);
+				fprintf(f, "%s%s: \n", ftp->f_objprefix, np);
 		}
 		else {
 			*cp = '\0';
 			if (och == 'o') {
-				fprintf(f, "%so:\n\t-cp $S/%so .\n\n",
-					tail(np), np);
+				fprintf(f, "%s%so:\n\t-cp $S/%so .\n\n",
+					ftp->f_objprefix, tail(np), np);
 				continue;
 			}
 			if (ftp->f_depends) {
-				fprintf(f, "%sln: $S/%s%c %s\n", tail(np),
-					np, och, ftp->f_depends);
+				fprintf(f, "%s%sln: $S/%s%c %s\n",
+					ftp->f_objprefix, tail(np), np, och,
+					ftp->f_depends);
 				fprintf(f, "\t${NORMAL_LINT}\n\n");
-				fprintf(f, "%so: $S/%s%c %s\n", tail(np),
-					np, och, ftp->f_depends);
+				fprintf(f, "%s%so: $S/%s%c %s\n",
+					ftp->f_objprefix, tail(np), np, och,
+					ftp->f_depends);
 			}
 			else {
-				fprintf(f, "%sln: $S/%s%c\n", tail(np),
-					np, och);
+				fprintf(f, "%s%sln: $S/%s%c\n",
+					ftp->f_objprefix, tail(np), np, och);
 				fprintf(f, "\t${NORMAL_LINT}\n\n");
-				fprintf(f, "%so: $S/%s%c\n", tail(np),
-					np, och);
+				fprintf(f, "%s%so: $S/%s%c\n",
+					ftp->f_objprefix, tail(np), np, och);
 			}
 		}
 		compilewith = ftp->f_compilewith;
 		if (compilewith == 0) {
 			const char *ftype = NULL;
-			static char cmd[128];
 
 			switch (ftp->f_type) {
-
 			case NORMAL:
 				ftype = "NORMAL";
 				break;
-
 			case PROFILING:
 				if (!profiling)
 					continue;
 				ftype = "PROFILE";
 				break;
-
 			default:
-				printf("config: don't know rules for %s\n", np);
+				fprintf(stderr,
+				    "config: don't know rules for %s\n", np);
 				break;
 			}
-			snprintf(cmd, sizeof(cmd), "${%s_%c%s}\n.if defined(NORMAL_CTFCONVERT) && !empty(NORMAL_CTFCONVERT)\n\t${NORMAL_CTFCONVERT}\n.endif", ftype,
+			snprintf(cmd, sizeof(cmd),
+			    "${%s_%c%s}", ftype,
 			    toupper(och),
 			    ftp->f_flags & NOWERROR ? "_NOWERROR" : "");
 			compilewith = cmd;
 		}
 		*cp = och;
-		fprintf(f, "\t%s\n\n", compilewith);
+		if (strlen(ftp->f_objprefix))
+			fprintf(f, "\t%s $S/%s\n", compilewith, np);
+		else
+			fprintf(f, "\t%s\n", compilewith);
+
+		if (!(ftp->f_flags & NO_OBJ))
+			fprintf(f, "\t${NORMAL_CTFCONVERT}\n\n");
+		else
+			fprintf(f, "\n");
 	}
 }
 
